==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/inc/lang/kk/lang.php <==
<?php
/**
 * kazakh language file
 *
 * @author Nurgozha Kaliaskarov astana08@gmail.com
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '"';
$lang['doublequoteclosing']    = '"';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Бұл мақаланы өңдеү';
$lang['btn_source']            = 'Бастапқы мәтінді көрсету';
$lang['btn_show']              = 'Бетті көрсету';
$lang['btn_create']            = 'Бұл бетті жасау';
$lang['btn_search']            = 'Іздеу';
$lang['btn_save']              = 'Сақтау';
$lang['btn_preview']           = 'Қарап шығу';
$lang['btn_top']               = 'Жоғары';
$lang['btn_newer']             = '<<жаңарақ';
$lang['btn_older']             = 'ескірек>>';
$lang['btn_revs']              = 'Қайта қараулары';
$lang['btn_recent']            = 'Жуырдағы өзгерістер';
$lang['btn_upload']            = 'Еңгізу';
$lang['btn_cancel']            = 'Болдырмау';
$lang['btn_index']             = 'Барлық беттері';
$lang['btn_secedit']           = 'Өңдеу';
$lang['btn_login']             = 'Кіру';
$lang['btn_logout']            = 'Шығу';
$lang['btn_admin']             = 'Басқару';
$lang['btn_update']            = 'Жаңарту';
$lang['btn_delete']            = 'Жою';
$lang['btn_back']              = 'Артқа';
$lang['btn_backlink']          = 'Кері сілтемелері';
$lang['btn_backtomedia']       = 'Медиафайлды таңдауға қайту';
$lang['btn_subscribe']         = 'Жазылуларды басқару';
$lang['btn_profile']           = 'Профильді жаңарту';
$lang['btn_reset']             = 'Түсіру';
$lang['btn_resendpwd']         = 'Шартты белгінi Өзгерту';
$lang['btn_draft']             = 'Шимайды өңдеу';
$lang['btn_recover']           = 'Шимайды қайтару';
$lang['btn_draftdel']          = 'Шимайды өшіру';
$lang['btn_revert']            = 'Қалпына келтіру';
$lang['btn_register']          = 'Тіркеу';
$lang['btn_apply']             = 'Қолдану/Енгізу';
$lang['loggedinas']            = 'түпнұсқамен кірген';
$lang['user']                  = 'Түпнұсқа';
$lang['pass']                  = 'Құпиясөз';
$lang['newpass']               = 'Жаңа құпиясөз';
$lang['oldpass']               = 'Ағымдағы құпиясөзді растау';
$lang['passchk']               = 'Тағы бір рет';
$lang['remember']              = 'Мені сақтау';
$lang['fullname']              = 'Шын аты';
$lang['email']                 = 'Е-пошта';
$lang['profile']               = 'Пайдаланушының профилі';
$lang['badlogin']              = 'Кешріңіз, түпнұсқа әлде құпиясөз дұрыс емес';
$lang['minoredit']             = 'Шағын өзгерістер';
$lang['draftdate']             = 'Шимай сақталғаны';
$lang['nosecedit']             = 'Бет өзгерді де бөлік тұралы ақпарат ескірді. Толық нұсқасы ашылды.';
$lang['regmissing']            = 'Кешіріңіз, барлық тармақтары толтыруыңыз керек.';
$lang['reguexists']            = 'Кешіріңіз, бұл түпнұскамен де пайдаланушы бар.';
$lang['regsuccess']            = 'Пайдаланушы қосылды әрі құпиясөзін электрондық поштаға жіберді.';
$lang['regsuccess2']           = 'Пайдаланушы қосылды.';
$lang['regmailfail']           = 'Құпиясөз хатты жіберуде қате болған сияқты. Мархабат, әкімшімен хабарласыңыз.';
$lang['regbadmail']            = 'Берілген электрондық пошта бұрыс деп көрінеді - егер бұл қателікті деп ойласаңыз, әкімшіге хабарлаңыз.';
$lang['regbadpass']            = 'Берілген екі құпиясөз бірдей емес, мархабат. қайтадан көріңіз.';
$lang['regpwmail']             = 'Сіздің DokuWiki құпиясөзіңіз';
$lang['reghere']               = 'Есебіңіз әлі жоқ па? Біреуін оңай ашыңыз';
$lang['profna']                = 'Бұл wiki профиль өзертуді қолдамайды';
$lang['profnochange']          = 'Өзгеріс жоқ, істейтін ештеңе жоқ.';
$lang['profnoempty']           = 'Бос есім не email рұқсат етілмейді.';
$lang['profchanged']           = 'Пайдаланушы профилі сәтті жаңартылған.';
$lang['pwdforget']             = 'Құпиясөзіңізді ұмыттыңызба? Жаңадан біреуін алыңыз';
$lang['resendna']              = 'Бұл wiki құпиясөзді қайта жіберуді қолдамайды.';
$lang['resendpwdmissing']      = 'Кешіріңіз, барлық тармақтары толтыруыңыз керек.';
$lang['resendpwdnouser']       = 'Кешіріңіз, бұл пайдаланушыны дерекқорымызда тапқан жоқпыз.';
$lang['resendpwdbadauth']      = 'Кешіріңіз, бұл түпнұсқалық коды бұрыс. Толық растау сілтемені пайдалануыңызды тексеріңіз.';
$lang['resendpwdconfirm']      = 'Растау сілтеме email арқылы жіберілді.';
$lang['resendpwdsuccess']      = 'Сіздің жаңа құпиясөзіңіз email арқылы жіберілді.';
$lang['license']               = 'Басқаша көрсетілген болмаса, бұл wiki-дің мазмұны келесі лицензия бойынша беріледі:';
$lang['licenseok']             = 'Ескерту: бұл бетті өңдеуіңізбен мазмұныңыз келесі лицензия бойынша беруге келесесіз:';
$lang['searchmedia']           = 'Іздеу файлдың атауы:';
$lang['searchmedia_in']        = '%s-мен іздеу:';
$lang['txt_upload']            = 'Еңгізетін файлды таңдау';
$lang['txt_filename']          = 'Келесідей еңгізу (қалауынша)';
$lang['txt_overwrt']           = 'Бар файлды қайта жазу';
$lang['lockedby']              = 'Осы уақытта тойтарылған';
$lang['lockexpire']            = 'Тойтару келесі уақытта бітеді';
$lang['js']['willexpire']      = 'Бұл бетті түзеу тойтаруыңыз бір минутта бітеді. Қақтығыс болмау және тойтару таймерді түсіру үшін қарап шығу пернені басыңыз.';
$lang['js']['notsavedyet']     = 'Сақталмаған өзгерістер жоғалатын болады.';
$lang['js']['searchmedia']     = 'Файлдарды іздеу';
$lang['js']['keepopen']        = 'Таңдаған соң терезе жаппаңыз';
$lang['js']['hidedetails']     = 'Ұсақтарды жасыру';
$lang['js']['mediatitle']      = 'Султеме теңшелімдері';
$lang['js']['mediadisplay']    = 'Сілтеме түрі';
$lang['js']['mediaalign']      = 'Тегістеуі';
$lang['js']['mediasize']       = 'Сүреттің өлшемі';
$lang['js']['mediatarget']     = 'Сілтеме нысанасы';
$lang['js']['mediaclose']      = 'Жабу';
$lang['js']['mediainsert']     = 'Еңгізу';
$lang['js']['mediadisplayimg'] = 'Бұл сүретті көрсету';
$lang['js']['mediadisplaylnk'] = 'Бұл сілтемені ғана көрсету,';
$lang['js']['mediasmall']      = 'Шағын нұсқасы';
$lang['js']['mediamedium']     = 'Орташа нұсқасы';
$lang['js']['medialarge']      = 'Үлкен нұсқасы';
$lang['js']['mediaoriginal']   = 'Түпнұсқалық нұсқасы';
$lang['js']['medialnk']        = 'Толық бетке сілтеме';
$lang['js']['mediadirect']     = 'Түпнұсқалыққа тұра сілтемесі';
$lang['js']['medianolnk']      = 'Сілтеме жоқ';
$lang['js']['medianolink']     = 'Суретті сілтетпеу';
$lang['js']['medialeft']       = 'Сүретті сол жаққа тегістеу';
$lang['js']['mediaright']      = 'Сүретті оң жаққа тегістеу';
$lang['js']['mediacenter']     = 'Сүретті ортаға тегістеу';
$lang['js']['medianoalign']    = 'Тегістеусіз';
$lang['js']['linkwiz']         = 'Сілтеме көмекшіci';
$lang['js']['media_diff']      = 'Өзгеліктердi Көрсету';
$lang['js']['media_select']    = 'Файлды тандау';
$lang['mediaselect']           = 'Медиа файлдар';
$lang['mediaroot']             = 'root';
$lang['yours']                 = 'Сендердің болжамыңыз';
$lang['created']               = 'ЖасалFан';
$lang['mail_new_user']         = 'Жаңа пайдаланушы';
$lang['qb_chars']              = 'Арнайы белгiлер';
$lang['img_backto']            = 'Қайта оралу';
$lang['img_format']            = 'Формат';
$lang['img_camera']            = 'Камера';
$lang['i_chooselang']          = 'Тіл таңдау';
$lang['i_retry']               = 'Қайталау';

==> dokuwiki_0.0.20140505.a+dfsg.orig.tar.gz: dokuwiki-2014-05-05a/inc/lang/kk/lang.php <==
<?php
/**
 * kazakh language file
 *
 * @author Nurgozha Kaliaskarov astana08@gmail.com
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '"';
$lang['doublequoteclosing']    = '"';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Бұл мақаланы өңдеү';
$lang['btn_source']            = 'Бастапқы мәтінді көрсету';
$lang['btn_show']              = 'Бетті көрсету';
$lang['btn_create']            = 'Бұл бетті жасау';
$lang['btn_search']            = 'Іздеу';
$lang['btn_save']              = 'Сақтау';
$lang['btn_preview']           = 'Қарап шығу';
$lang['btn_top']               = 'Жоғары';
$lang['btn_newer']             = '<<жаңарақ';
$lang['btn_older']             = 'ескірек>>';
$lang['btn_revs']              = 'Қайта қараулары';
$lang['btn_recent']            = 'Жуырдағы өзгерістер';
$lang['btn_upload']            = 'Еңгізу';
$lang['btn_cancel']            = 'Болдырмау';
$lang['btn_index']             = 'Барлық беттері';
$lang['btn_secedit']           = 'Өңдеу';
$lang['btn_login']             = 'Кіру';
$lang['btn_logout']            = 'Шығу';
$lang['btn_admin']             = 'Басқару';
$lang['btn_update']            = 'Жаңарту';
$lang['btn_delete']            = 'Жою';
$lang['btn_back']              = 'Артқа';
$lang['btn_backlink']          = 'Кері сілтемелері';
$lang['btn_backtomedia']       = 'Медиафайлды таңдауға қайту';
$lang['btn_subscribe']         = 'Жазылуларды басқару';
$lang['btn_profile']           = 'Профильді жаңарту';
$lang['btn_reset']             = 'Түсіру';
$lang['btn_resendpwd']         = 'Шартты белгінi Өзгерту';
$lang['btn_draft']             = 'Шимайды өңдеу';
$lang['btn_recover']           = 'Шимайды қайтару';
$lang['btn_draftdel']          = 'Шимайды өшіру';
$lang['btn_revert']            = 'Қалпына келтіру';
$lang['btn_register']          = 'Тіркеу';
$lang['btn_apply']             = 'Қолдану/Енгізу';
$lang['loggedinas']            = 'түпнұсқамен кірген';
$lang['user']                  = 'Түпнұсқа';
$lang['pass']                  = 'Құпиясөз';
$lang['newpass']               = 'Жаңа құпиясөз';
$lang['oldpass']               = 'Ағымдағы құпиясөзді растау';
$lang['passchk']               = 'Тағы бір рет';
$lang['remember']              = 'Мені сақтау';
$lang['fullname']              = 'Шын аты';
$lang['email']                 = 'Е-пошта';
$lang['profile']               = 'Пайдаланушының профилі';
$lang['badlogin']              = 'Кешріңіз, түпнұсқа әлде құпиясөз дұрыс емес';
$lang['minoredit']             = 'Шағын өзгерістер';
$lang['draftdate']             = 'Шимай сақталғаны';
$lang['nosecedit']             = 'Бет өзгерді де бөлік тұралы ақпарат ескірді. Толық нұсқасы ашылды.';
$lang['regmissing']            = 'Кешіріңіз, барлық тармақтары толтыруыңыз керек.';
$lang['reguexists']            = 'Кешіріңіз, бұл түпнұскамен де пайдаланушы бар.';
$lang['regsuccess']            = 'Пайдаланушы қосылды әрі құпиясөзін электрондық поштаға жіберді.';
$lang['regsuccess2']           = 'Пайдаланушы қосылды.';
$lang['regmailfail']           = 'Құпиясөз хатты жіберуде қате болған сияқты. Мархабат, әкімшімен хабарласыңыз.';
$lang['regbadmail']            = 'Берілген электрондық пошта бұрыс деп көрінеді - егер бұл қателікті деп ойласаңыз, әкімшіге хабарлаңыз.';
$lang['regbadpass']            = 'Берілген екі құпиясөз бірдей емес, мархабат. қайтадан көріңіз.';
$lang['regpwmail']             = 'Сіздің DokuWiki құпиясөзіңіз';
$lang['reghere']               = 'Есебіңіз әлі жоқ па? Біреуін оңай ашыңыз';
$lang['profna']                = 'Бұл wiki профиль өзертуді қолдамайды';
$lang['profnochange']          = 'Өзгеріс жоқ, істейтін ештеңе жоқ.';
$lang['profnoempty']           = 'Бос есім не email рұқсат етілмейді.';
$lang['profchanged']           = 'Пайдаланушы профилі сәтті жаңартылған.';
$lang['pwdforget']             = 'Құпиясөзіңізді ұмыттыңызба? Жаңадан біреуін алыңыз';
$lang['resendna']              = 'Бұл wiki құпиясөзді қайта жіберуді қолдамайды.';
$lang['resendpwdmissing']      = 'Кешіріңіз, барлық тармақтары толтыруыңыз керек.';
$lang['resendpwdnouser']       = 'Кешіріңіз, бұл пайдаланушыны дерекқорымызда тапқан жоқпыз.';
$lang['resendpwdbadauth']      = 'Кешіріңіз, бұл түпнұсқалық коды бұрыс. Толық растау сілтемені пайдалануыңызды тексеріңіз.';
$lang['resendpwdconfirm']      = 'Растау сілтеме email арқылы жіберілді.';
$lang['resendpwdsuccess']      = 'Сіздің жаңа құпиясөзіңіз email арқылы жіберілді.';
$lang['license']               = 'Басқаша көрсетілген болмаса, бұл wiki-дің мазмұны келесі лицензия бойынша беріледі:';
$lang['licenseok']             = 'Ескерту: бұл бетті өңдеуіңізбен мазмұныңыз келесі лицензия бойынша беруге келесесіз:';
$lang['searchmedia']           = 'Іздеу файлдың атауы:';
$lang['searchmedia_in']        = '%s-мен іздеу:';
$lang['txt_upload']            = 'Еңгізетін файлды таңдау';
$lang['txt_filename']          = 'Келесідей еңгізу (қалауынша)';
$lang['txt_overwrt']           = 'Бар файлды қайта жазу';
$lang['lockedby']              = 'Осы уақытта тойтарылған';
$lang['lockexpire']            = 'Тойтару келесі уақытта бітеді';
$lang['js']['willexpire']      = 'Бұл бетті түзеу тойтаруыңыз бір минутта бітеді. Қақтығыс болмау және тойтару таймерді түсіру үшін қарап шығу пернені басыңыз.';
$lang['js']['notsavedyet']     = 'Сақталмаған өзгерістер жоғалатын болады.';
$lang['js']['searchmedia']     = 'Файлдарды іздеу';
$lang['js']['keepopen']        = 'Таңдаған соң терезе жаппаңыз';
$lang['js']['hidedetails']     = 'Ұсақтарды жасыру';
$lang['js']['mediatitle']      = 'Султеме теңшелімдері';
$lang['js']['mediadisplay']    = 'Сілтеме түрі';
$lang['js']['mediaalign']      = 'Тегістеуі';
$lang['js']['mediasize']       = 'Сүреттің өлшемі';
$lang['js']['mediatarget']     = 'Сілтеме нысанасы';
$lang['js']['mediaclose']      = 'Жабу';
$lang['js']['mediainsert']     = 'Еңгізу';
$lang['js']['mediadisplayimg'] = 'Бұл сүретті көрсету';
$lang['js']['mediadisplaylnk'] = 'Бұл сілтемені ғана көрсету,';
$lang['js']['mediasmall']      = 'Шағын нұсқасы';
$lang['js']['mediamedium']     = 'Орташа нұсқасы';
$lang['js']['medialarge']      = 'Үлкен нұсқасы';
$lang['js']['mediaoriginal']   = 'Түпнұсқалық нұсқасы';
$lang['js']['medialnk']        = 'Толық бетке сілтеме';
$lang['js']['mediadirect']     = 'Түпнұсқалыққа тұра сілтемесі';
$lang['js']['medianolnk']      = 'Сілтеме жоқ';
$lang['js']['medianolink']     = 'Суретті сілтетпеу';
$lang['js']['medialeft']       = 'Сүретті сол жаққа тегістеу';
$lang['js']['mediaright']      = 'Сүретті оң жаққа тегістеу';
$lang['js']['mediacenter']     = 'Сүретті ортаға тегістеу';
$lang['js']['medianoalign']    = 'Тегістеусіз';
$lang['js']['linkwiz']         = 'Сілтеме көмекшіci';
$lang['js']['media_diff']      = 'Өзгеліктердi Көрсету';
$lang['js']['media_select']    = 'Файлды тандау';
$lang['mediaselect']           = 'Медиа файлдар';
$lang['mediaroot']             = 'root';
$lang['yours']                 = 'Сендердің болжамыңыз';
$lang['created']               = 'ЖасалFан';
$lang['mail_new_user']         = 'Жаңа пайдаланушы';
$lang['qb_chars']              = 'Арнайы белгiлер';
$lang['btn_img_backto']            = 'Қайта оралу %s';
$lang['img_format']            = 'Формат';
$lang['img_camera']            = 'Камера';
$lang['i_chooselang']          = 'Тіл таңдау';
$lang['i_retry']               = 'Қайталау';
